#ifndef NT2_INCLUDE_FUNCTIONS_REM_PIO2_STRAIGHT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REM_PIO2_STRAIGHT_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/rem_pio2_straight.hpp>

#endif
